% =============================================================================
%
% solve_Hopf_plus.m
% CBP 02-02-21
% Solver for Salamander CPG - Hopf oscillator plus one phas shift
%
% =============================================================================

global alpha mu omega tau k

clf;

tstart = 0;
tend = input('Input end time ');

% Get parameters and calc coefficients
dPhase = (pi/180)*input('Input phase shift degrees');
alpha =1.0;
mu = input('Input mu ');
omega = 2*pi*input('Input frequency in cycles per sec ');
tau = tan(dPhase)/omega
k = sqrt(tau*tau*omega*omega + 1);

% Set all variable initial conditions to 0.5
xinit = zeros(4,1);
for i = 1:4
  xinit(i) = 0.5;
end

% Run the ODE solver
options = odeset('RelTol',1e-6,'AbsTol',1e-6,'InitialStep',tend/200,'MaxStep',tend/200);
[t,y] = ode45(@rhs_Hopf_plus,[tstart,tend],xinit,options);

% Plot op of oscillator and delay neuron
figure(1);
plot(t,y(:,1),'r',t,y(:,3),'g');
ylabel('Oscillator output (red) Phase lag (green)');
figure(2);

% Do fancy plot of phase chasing
x1=0;y1=0;
x2=0;y2=0;
xPrev = 0;
xPrev2 = 0;
yPrev = 0;
yPrev2=0;
AA = 2*mu;
i = 1;
hold on;
  axis([-AA,AA,-AA,AA]);
  grid;
while i < length(t) - 1

  x1 = y(i,1);
  y1 = y(i,2);
  x2 = y(i,3);
  y2 = y(i,4);
  
  plot(x1,y1,'r.','MarkerSize',20);
  plot(x2,y2,'g.','MarkerSize',20);  
  plot(xPrev,yPrev,'w.','MarkerSize',24);    
  plot(xPrev2,yPrev2,'w.','MarkerSize',24);  
  
  xPrev = x1;
  yPrev = y1;
  xPrev2 = x2;
  yPrev2 = y2;
 
  drawnow;
  i++;
endwhile
hold off;